==> ejc-equipment-impl-3.0.0-20220801.073001-355-sources.jar: com/ejianc/business/equipment/service/IPurchaseContractService.java <==
package com.ejianc.business.equipment.service;

import com.ejianc.business.equipment.bean.PurchaseContractEntity;
import com.ejianc.business.equipment.controller.SqlParam;
import com.ejianc.business.equipment.vo.EquipmentReportVo;
import com.ejianc.business.equipment.vo.PurchaseContractVO;
import com.ejianc.business.equipment.vo.SettlementVO;
import com.ejianc.business.equipment.vo.warn.EquipmentWarnVo;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.util.List;
import java.util.Map;

public interface IPurchaseContractService extends IBaseService<PurchaseContractEntity> {

    /**
     * 保存或修改信息
     *
     * @param PurchaseContractVo
     * @return
     */
    CommonResponse<PurchaseContractVO> saveOrUpdate(PurchaseContractVO PurchaseContractVo);

    /**
     * 根据主键ID查询详情
     *
     * @param id
     * @return
     */
    PurchaseContractVO queryDetail(Long id);

    /**
     * 删除信息
     *
     * @param vos
     */
    void deletePurchaseContract(List<PurchaseContractVO> vos);

    /**
     * 汇总合同原始金额--现合同金额
     *
     * @param queryParam
     */
    Map<String, Object> countContractAmount(QueryParam queryParam);


    List<Map<String, Object>> querySettleWarnContract(List<SqlParam> sqlParamList);

    List<Map<String, Object>> queryPayWarnContract(List<SqlParam> sqlParamList);

    List<Map<String, Object>> queryPrePayWarnContract(List<SqlParam> sqlParamList);

    List<Map<String, Object>> invoicePayMnyWarn(List<SqlParam> sqlParamList);

    List<Map<String, Object>> invoiceContractMnyWarn(List<SqlParam> sqlParamList);

    List<EquipmentWarnVo> equipmentProjectOutMny(List<Long> tenantIds);

    List<EquipmentReportVo> getMonthEquipmentMny(Long projectId, Integer lastDay);

    List<EquipmentReportVo> getEquipment(Long projectId);

    List<SettlementVO> getSettleMny(List<Long> projectIds);
}

==> ejc-equipment-impl-3.0.0-20221020.061006-380-sources.jar: com/ejianc/business/equipment/service/IPurchaseContractService.java <==
package com.ejianc.business.equipment.service;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.equipment.bean.PurchaseContractEntity;
import com.ejianc.business.equipment.controller.SqlParam;
import com.ejianc.business.equipment.vo.EquipmentReportVo;
import com.ejianc.business.equipment.vo.PurchaseContractVO;
import com.ejianc.business.equipment.vo.SettlementVO;
import com.ejianc.business.equipment.vo.warn.EquipmentWarnVo;
import com.ejianc.business.equipment.vo.ParamsCheckVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

public interface IPurchaseContractService extends IBaseService<PurchaseContractEntity> {

    /**
     * 保存或修改信息
     *
     * @param PurchaseContractVo
     * @return
     */
    CommonResponse<PurchaseContractVO> saveOrUpdate(PurchaseContractVO PurchaseContractVo);

    /**
     * 根据主键ID查询详情
     *
     * @param id
     * @return
     */
    PurchaseContractVO queryDetail(Long id);

    /**
     * 删除信息
     *
     * @param vos
     */
    void deletePurchaseContract(List<PurchaseContractVO> vos);

    /**
     * 汇总合同原始金额--现合同金额
     *
     * @param queryParam
     */
    Map<String, Object> countContractAmount(QueryParam queryParam);


    List<Map<String, Object>> querySettleWarnContract(List<SqlParam> sqlParamList);

    List<Map<String, Object>> queryPayWarnContract(List<SqlParam> sqlParamList);

    List<Map<String, Object>> queryPrePayWarnContract(List<SqlParam> sqlParamList);

    List<Map<String, Object>> invoicePayMnyWarn(List<SqlParam> sqlParamList);

    List<Map<String, Object>> invoiceContractMnyWarn(List<SqlParam> sqlParamList);

    List<EquipmentWarnVo> equipmentProjectOutMny(List<Long> tenantIds);

    List<EquipmentReportVo> getMonthEquipmentMny(Long projectId, Integer lastDay);

    List<EquipmentReportVo> getEquipment(Long projectId);

    List<SettlementVO> getSettleMny(List<Long> projectIds);

    BigDecimal totalContractMny(PurchaseContractVO vo);
    /**
     * 参数控制
     *
     * @param vo 预算机械费总金额  设备采购总金额
     *
     * @return {@link ParamsCheckVO}
     */
    ParamsCheckVO checkParams(PurchaseContractVO vo);
}
